pub struct NedTimezoneResponse1 {
pub id: usize,
pub identifier: Option<&'static str>,
pub description: &'static str,
pub dst_description: Option<&'static str>,
pub offset: &'static str,
pub zone: f32,
pub raw_offset: i32,
}Expand description
The response type for the NED timezone endpoint when found.
Currently ingested version of this data set is here.
Fields
id: usizeThe index of this timezone in the global static cache.
This is not stable across builds or new data sets. It is merely unique during a single build.
identifier: Option<&'static str>The IANA time zone identifier (e.g., America/Los_Angeles).
description: &'static strThe countries and regions this zone covers.
dst_description: Option<&'static str>The daylight savings time information for this zone.
offset: &'static strThe UTC offset in display form (e.g., UTC-8:00).
zone: f32The UTC offset in hours (e.g., -8).
raw_offset: i32The UTC offset in seconds (e.g., -28800).