pub struct OsmTimezoneResponse1 {
pub id: usize,
pub identifier: &'static str,
pub short_identifier: String,
pub offset: String,
pub raw_offset: i32,
pub raw_base_offset: i32,
pub raw_dst_offset: i32,
pub zone: f32,
pub current_time: String,
}Expand description
The response type for the OSM timezone endpoint when found.
Currently ingested version of this data set is here.
Fields
id: usizeThe index of this timezone in the global static cache.
This is not stable across builds or new data sets. It is merely unique during a single build.
identifier: &'static strThe IANA time zone identifier (e.g., America/Los_Angeles).
short_identifier: StringThe abbreviated name of the offset currently in effect (e.g., PDT).
offset: StringThe current UTC offset in display form (e.g., UTC-8:00).
raw_offset: i32The current UTC offset in seconds, including any daylight savings adjustment (e.g., -28800).
raw_base_offset: i32The standard UTC offset in seconds, excluding daylight savings (e.g., -28800).
raw_dst_offset: i32The daylight savings adjustment in seconds, or 0 when it is not in effect.
zone: f32The current UTC offset in hours (e.g., -8).
current_time: StringThe current time in this timezone, as an RFC 3339 timestamp.