pub struct OsmAdmin {
pub id: usize,
pub relation_id: u64,
pub name: EncodableString,
pub level: usize,
pub geometry: EncodableGeometry,
}Expand description
A representation of the OpenStreetMap
geojson
geojson::Features for administrative areas.
Fields
id: usizeThe index of the OsmAdmin in the global static cache.
This is is not stable across builds or new data sets. It is merely unique during a single build.
relation_id: u64The OSM relation id of the admin area (e.g., 1473947), or 0 if the source boundary was
not relation-backed. Unlike OsmAdmin::id, this is stable across builds and data sets.
name: EncodableStringThe name of the OsmAdmin (e.g., Burkina Faso).
level: usizeThe level of the OsmAdmin (e.g., 3).
geometry: EncodableGeometryThe geometry of the OsmAdmin.